package handlers

import (
	"net/http"

	"github.com/go-openapi/runtime"

	"orus.io/orus-io/rednerd/models"
)

/* DocumentFileResponse.
 */
type DocumentFileResponse struct {
	Document *models.Document
	ETag     string
}

// NewDocumentFileResponse creates AccountTemplatePreviewOK with default headers values.
func NewDocumentFileResponse() *DocumentFileResponse {
	return &DocumentFileResponse{}
}

// WithETag set the response ETag header.
func (o *DocumentFileResponse) WithETag(etag string) *DocumentFileResponse {
	o.ETag = etag

	return o
}

// SetETag set the response ETag header.
func (o *DocumentFileResponse) SetETag(etag string) {
	o.ETag = etag
}

// WithDocument set the document to return.
func (o *DocumentFileResponse) WithDocument(document *models.Document) *DocumentFileResponse {
	o.Document = document

	return o
}

// SetContentDisposition sets the contentDisposition to the account template preview o k response.
func (o *DocumentFileResponse) SetDocument(document *models.Document) {
	o.Document = document
}

// WriteResponse to the client.
func (o *DocumentFileResponse) WriteResponse(rw http.ResponseWriter, producer runtime.Producer) {
	// response header Content-Type
	rw.Header().Set("Content-Type", o.Document.Type)

	if o.ETag != "" {
		rw.Header().Set("ETag", o.ETag)
	}

	payload, err := o.Document.Bytes()
	if err != nil {
		panic(err)
	}

	rw.WriteHeader(http.StatusOK)

	if _, err := rw.Write(payload); err != nil {
		panic(err)
	}
}
