package handlers_test

import (
	"net/http"
	"testing"

	"github.com/stretchr/testify/require"

	"orus.io/orus-io/rednerd/models"
	"orus.io/orus-io/rednerd/testutils/apitester"
)

func TestUserGet(t *testing.T) {
	tester := apitester.NewAPITester(t, nil)
	defer tester.Close()

	// login as admin and create a user
	tester.Login("admin", "admin")
	tester.CreateUser("johndoe", "johndoe")

	// adding some dummy activity for the user JohnDoe
	qtyCurrentMonth := 4
	qtyLastMonth := 2
	tester.AddUserActivity("johndoe",
		qtyCurrentMonth, qtyLastMonth)

	tester.Logout()

	t.Run("unauthorized", func(t *testing.T) {
		// try and get the list as johndoe_1
		tester.Login("johndoe", "johndoe")
		defer tester.Logout()
		_ = tester.APITest("user_get").
			Get("/api/v1/user/johndoe").
			Expect(t).
			Status(http.StatusUnauthorized).
			End()
	})
	t.Run("basic", func(t *testing.T) {
		tester.Login("admin", "admin")
		defer tester.Logout()
		r := tester.APITest("user_get").
			Get("/api/v1/user/johndoe").
			Expect(t).
			Status(http.StatusOK).
			End()

		var user models.Userinfo

		r.JSON(&user)
		stats := user.Activity.RenderStats
		expectedTotal := qtyCurrentMonth + qtyLastMonth
		require.Equal(t, int64(expectedTotal), stats.Total)
		require.Equal(t, int64(qtyCurrentMonth), stats.CurrentMonth)
		require.Equal(t, int64(qtyLastMonth), stats.LastMonth)
	})
}
