package tests

import (
	"encoding/base64"
	"fmt"
	"os"
	"testing"
	"time"

	"github.com/stretchr/testify/assert"
	"github.com/stretchr/testify/require"
	"github.com/vincent-petithory/dataurl"

	"orus.io/orus-io/rednerd/cmd/rednerd/cmd"
	"orus.io/orus-io/rednerd/engines/wpd"
	"orus.io/orus-io/rednerd/models"
	"orus.io/orus-io/rednerd/restapi"
	"orus.io/orus-io/rednerd/testutils/apitester"
)

func TestWPDURI(t *testing.T) {
	engineOptions := cmd.NewEngineOptions()

	require.NoError(t, engineOptions.SetupEngineOptions(nil))
	engineOptions.SetOptions(
		"WPD", &wpd.EngineOptions{
			WorkerPoolSize: 10,
		})

	tester := apitester.NewAPITester(
		t, &engineOptions, func(s *restapi.Server) {
			s.WriteTimeout = time.Minute * 5
		})
	defer tester.Close()

	defer tester.Logout()
	tester.Login("admin", "admin")

	tester.CreateUser("janedoe", "janedoe")
	tester.Login("janedoe", "janedoe")

	var result []*models.Document

	// Read the file
	image, err := os.ReadFile("nicolas_cage.jpg")
	require.NoError(t, err)

	dataURL := dataurl.EncodeBytes(image)

	body := fmt.Sprintf(
		"<html><body><h1>im nicolas cage</h1><img src='%s' alt='Nicolas Cage'></body></html>",
		dataURL,
	)
	tester.Render(
		&models.RenderRequest{
			Accept: "application/pdf",
			Document: &models.Document{
				Type:       "text/html",
				BodyFormat: "text",
				Body:       body,
			},
		},
		&result,
	)
	require.Equal(t, 1, len(result))

	if body, err := base64.StdEncoding.DecodeString(
		result[0].Body,
	); assert.NoError(t, err) && assert.NotZero(t, len(body)) {
		require.NoError(t, os.WriteFile("nicolas_cage.pdf", body, 0o600))
	}
}
