package apitester

import (
	"net/http"
	"time"

	"github.com/stretchr/testify/require"
	"orus.io/orus-io/go-orusapi/database"

	"orus.io/orus-io/rednerd/models"
)

// CreateUser creates a new user and sets its password.
func (tester *APITester) CreateUser(username, password string) {
	apitest := tester.APITest("user_create")
	if tester.debug {
		apitest = apitest.Debug()
	}

	user := models.Userinfo{
		Username: username,
		Email:    username + "@mydomain.fr",
	}
	r := apitest.
		Post("/api/v1/user").
		JSON(&user).
		Expect(tester.t).
		Status(http.StatusCreated).
		End()

	var info models.Userinfo

	r.JSON(&info)
	require.Equal(tester.t, username, info.Username)
	require.False(tester.t, info.IsAdmin)

	// set password.
	tester.SetPassword(username, password)
}

// GetUser returns the uer by username.
func (tester *APITester) GetUser(username string, user *models.Userinfo) {
	apitest := tester.APITest("user_get")
	if tester.debug {
		apitest = apitest.Debug()
	}

	r := apitest.
		Get("/api/v1/user/" + username).
		Expect(tester.t).
		Status(http.StatusOK).
		End()
	r.JSON(user)
	require.Equal(tester.t, username, user.Username)
}

// ListUsers returns all the users.
func (tester *APITester) ListUsers(users *[]*models.Userinfo) {
	apitest := tester.APITest("user_list")
	if tester.debug {
		apitest = apitest.Debug()
	}

	r := apitest.
		Get("/api/v1/user").
		Expect(tester.t).
		Status(http.StatusOK).
		End()
	r.JSON(users)
}

func (tester *APITester) AddUserActivity(
	username string,
	qtyCurrentMonth, qtyLastMonth int,
) {
	renderList := make([]*models.RenderLog, 0, qtyCurrentMonth+qtyLastMonth)

	for range qtyCurrentMonth {
		rd := models.NewRenderLog(time.Now(), "text", "mjml", username)
		rd.SetDuration(time.Second)
		renderList = append(renderList, rd)
	}

	for range qtyLastMonth {
		rd := models.NewRenderLog(time.Now().AddDate(0, -1, 0), "text", "mjml", username)
		rd.SetDuration(time.Second)
		renderList = append(renderList, rd)
	}

	for _, rlog := range renderList {
		_, err := database.Exec(tester.DB, database.SQLInsert(rlog), &tester.Logger)
		require.NoError(tester.t, err)
	}
}
